@@ -1,42 +1,42 @@
 // texts to translate
 var texts = {
-    netselection : "Grafo",
+    graph : "gràfic",
     nodes : "Nodes",
     general: "General",
     links: "Enllaços",
     apply: "Aplicar",
     filter: "Filtre",
+    isolate: "Aïllar",
     select: "Escull",
     clear: "Net",
     add: "Afegeix",
-    simpleadvanced: "Senzill/Avançat",
     nodesattributes: "Atributs dels nodes",
     linksattributes: "Atributs dels enllaços",
-    noitemsselected: "Cap element seleccionat",
-    alertnonodes: "Cap node seleccionat! Prem els nodes per a seleccionar-los.",
-    alertnonodestable: "No hi ha res seleccionat a la taula!",
+    noitemsselected: "Selecciona un node en el gràfic per veure els atributs.",
     repulsion: "Repulsió",
     distance: "Distància",
     loading: "Carregant...",
     pdfexport: "PDF exportació",
     svgexport: "SVG exportació",
-    showhidelegend: "Mostra/oculta llegenda",
-    showhideaxes: "Mostra/oculta eixos",
-    showhideimages: "Mostra/oculta imatges",
+    pngexport: "PNG exportació",
+    showHelp: "Mostrar ajuda",
+    showhidelegend: "Llegenda",
+    Image: "Imatge",
+    showhideaxes: "Eixos",
     showhidesidebar: "Mostra/oculta barra lateral",
     showhidebuttons: "Mostra/oculta botons",
     showhidetables: "Mostra/oculta taules",
-    stopresume: "Aturar/Rependre",
-    netheatmap: "Xarxa/map de calor",
-    isolateselection: "Filtre",
-    resetfilter: "Restablir filtre",
-    selectall: "Selecció tots/cap nodes",
+    stopresume: "Dinàmic",
+    heatmap: "Heatmap",
+    resetfilter: "Elimina els filtres",
+    selectall: "Selecció tots",
     selectneighbors: "Afegir veïns",
-    egoNet: "EgoNet",
-    expandcollapse: "Expandir/contraure",
+    expand: "Expandir",
+    collapse: "Contraure",
+    Reverse: "Reverse",
     tableselection: "Marcats en la taula",
     reset: "Restaurar",
-    directional: "Mostra/oculta fletxes",
+    directional: "Fletxes",
     degree: "Grau",
     none: "Cap",
     downloadtable: "Descarrega la taula",
@@ -64,6 +64,22 @@ var texts = {
     Weight: "Pes",
     Intensity: "Intensitat",
     Text: "Text",
+    LabelInfo: "Label",
+    LabelSizeInfo: "Label Size",
+    GroupInfo: "Group",
+    OrderInfo: "Order",
+    OrderAInfo: "Ascending Order",
+    OrderDInfo: "Descending Order",
+    SizeInfo: "Size",
+    ColorInfo: "Color",
+    ShapeInfo: "Shape",
+    LegendInfo: "Legend",
+    WidthInfo: "Width",
+    WeightInfo: "Weight",
+    IntensityInfo: "Intensity",
+    TextInfo: "Text",
+    Layout: "Disposició",
+    LayoutInfo: "Disposició",
     Show: "Mostra",
     Hide: "Oculta",
     circle: "cercle",
@@ -72,12 +88,26 @@ var texts = {
     square: "quadrat",
     "triangle-down": "triangle-avall",
     "triangle-up": "triangle-amunt",
-    trianglesquare: "Triangle/cuadrat",
-    selectacolorscale: "Selecciona una escala de color",
+    trianglesquare: "Triangle",
+    selectacolorscale: "Selecciona una escala de color per ",
+    selectacolor: "Selecciona un color per ",
+    selectashape: "Selecciona una forma per ",
+    selectattribute: "Selecciona un atribut per mostrar com a color ",
     outof: "de",
     scenarios: "nombre d'escenaris",
     resetzoom: "Restaurar zoom",
+    zoomin: "Ampliar zoom",
+    zoomout: "Disminuir zoom",
     removefilter: "Treure filtre",
-    alertrecordheatmap: "el mapa de calor no es pot gravar.",
-    speed: "Velocitat"
+    alertrecordheatmap: "el heatmap no es pot gravar.",
+    speed: "Velocitat",
+    searchanode: "Cerqueu un node",
+    goback: "Tornar",
+    newtab: "Obriu a la pestanya nova",
+    tools: "Eines",
+    poweredby: "Fet amb",
+    isolateInfo: "Permet veure únicament el node (o nodes) seleccionat",
+    filterInfo: "Permet veure el node (o nodes) seleccionat i la seva xarxa (nodes amb els quals està relacionat)",
+    selectcustomcolor: "Selecciona un color personalitzat",
+    filterselection: "Filtrar selecció"
   };
