@@ -1,44 +1,69 @@
+var categoryColors = [
+  "#1f77b4", // blue
+  "#ff7f0e", // orange
+  "#2ca02c", // green
+  "#e377c2", // pink
+  "#d62728", // red
+  "#bcbd22", // lime
+  "#9467bd", // purple
+  "#8c564b", // brown
+  "#7f7f7f", // grey
+  "#17becf", // cyan
+  "#aec7e8", // light blue
+  "#ffbb78", // light orange
+  "#98df8a", // light green
+  "#f7b6d2", // light pink
+  "#ff9896", // light red
+  "#dbdb8d", // light lime
+  "#c5b0d5", // light purple
+  "#c49c94", // light brown
+  "#c7c7c7", // light grey
+  "#9edae5" // light cyan
+];
+
 var colorScales = {
-  "WhBu": [
-      "#ffffff",
-      "#8fbbd9",
-      "#1f77b4"
-    ],
-  "BuWh": [
-      "#1f77b4",
-      "#8fbbd9",
-      "#ffffff"
-    ],
-  "WhRd": [
-      "#ffffff",
-      "#ea9394",
-      "#d62728"
-    ],
-  "RdWh": [
-      "#d62728",
-      "#ea9394",
-      "#ffffff"
-    ],
   "WhGn": [
       "#ffffff",
-      "#96d096",
       "#2ca02c"
     ],
   "GnWh": [
       "#2ca02c",
-      "#96d096",
+      "#ffffff"
+    ],
+  "WhRd": [
+      "#ffffff",
+      "#d62728"
+    ],
+  "RdWh": [
+      "#d62728",
       "#ffffff"
     ],
   "WhBk": [
       "#ffffff",
-      "#808080",
       "#000000"
     ],
   "BkWh": [
       "#000000",
-      "#808080",
       "#ffffff"
     ],
+  "WhBu": [
+      "#ffffff",
+      "#1f77b4"
+    ],
+  "BuWh": [
+      "#1f77b4",
+      "#ffffff"
+    ],
+  "GnWhRd": [
+      "#2ca02c",
+      "#ffffff",
+      "#d62728"
+    ],
+  "RdWhGn": [
+      "#d62728",
+      "#ffffff",
+      "#2ca02c"
+    ],
   "BkWhRd": [
       "#000000",
       "#ffffff",
@@ -49,15 +74,25 @@ var colorScales = {
       "#ffffff",
       "#000000"
     ],
-  "GnWhRd": [
-      "#2ca02c",
+  "BuWhRd": [
+      "#1f77b4",
       "#ffffff",
       "#d62728"
     ],
-  "RdWhGn": [
+  "RdWhBu": [
       "#d62728",
       "#ffffff",
-      "#2ca02c"
+      "#1f77b4"
+    ],
+  "YlWhBu": [
+      "#bcbd22",
+      "#ffffff",
+      "#1f77b4"
+    ],
+  "BuWhYl": [
+      "#1f77b4",
+      "#ffffff",
+      "#bcbd22"
     ],
   "GnBkRd": [
       "#2ca02c",
@@ -71,55 +106,34 @@ var colorScales = {
     ],
   "BkRd": [
       "#000000",
-      "#6b1414",
       "#d62728"
     ],
   "RdBk": [
       "#d62728",
-      "#6b1414",
       "#000000"
     ],
   "BuRd": [
       "#1f77b4",
-      "#7a4f6e",
       "#d62728"
     ],
   "RdBu": [
       "#d62728",
-      "#7a4f6e",
       "#1f77b4"
     ],
   "YlBu": [
       "#bcbd22",
-      "#6d9a6b",
       "#1f77b4"
     ],
   "BuYl": [
       "#1f77b4",
-      "#6d9a6b",
       "#bcbd22"
-    ]
+    ],
+  "BuGn": ["#6720D6", "#0BD638"],
+  "PiGn": ["#D6249D", "#70D661"],
+  "YlPi": ["#D6C30C", "#8A013C"],
+  "BuPi": ["#24D6C0", "#D618CC"],
+  "OrPu": ["#D68706", "#811CD6"],
+  "PiWh": ["#D618CC", "#FFFFFF"],
+  "OrWh": ["#D68D01", "#FFFFFF"],
+  "YlWh": ["#D6D31F", "#FFFFFF"]
 };
-
-var categoryColors = [
-  "#1f77b4", // blue
-  "#2ca02c", // green
-  "#d62728", // red
-  "#9467bd", // purple
-  "#ff7f0e", // orange
-  "#8c564b", // brown
-  "#e377c2", // pink
-  "#7f7f7f", // grey
-  "#bcbd22", // lime
-  "#17becf", // cyan
-  "#aec7e8", // light blue
-  "#98df8a", // light green
-  "#ff9896", // light red
-  "#c5b0d5", // light purple
-  "#ffbb78", // light orange
-  "#c49c94", // light brown
-  "#f7b6d2", // light pink
-  "#c7c7c7", // light grey
-  "#dbdb8d", // light lime
-  "#9edae5" // light cyan
-];
